@@ -1,6 +1,6 @@
 /*
  *  GNOME Logs - View and search logs
- *  Copyright (C) 2013  Red Hat, Inc.
+ *  Copyright (C) 2013, 2014, 2015  Red Hat, Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -28,6 +28,12 @@
 #include "gl-util.h"
 #include "gl-window.h"
 
+struct _GlApplication
+{
+    /*< private >*/
+    GtkApplication parent_instance;
+};
+
 typedef struct
 {
     GSettings *desktop;
