@@ -45,6 +45,8 @@ gboolean gl_event_toolbar_handle_back_button_event (GlEventToolbar *toolbar,
 void gl_event_toolbar_set_mode (GlEventToolbar *toolbar,
                                 GlEventToolbarMode mode);
 void gl_event_toolbar_add_boots (GlEventToolbar *toolbar, GArray *boot_ids);
+void gl_event_toolbar_change_current_boot (GlEventToolbar *toolbar,
+                                           const gchar *current_boot);
 
 G_END_DECLS
 
