@@ -223,6 +223,7 @@ gl_event_view_row_constructed (GObject *object)
 
         context = gtk_widget_get_style_context (GTK_WIDGET (priv->category_label));
         gtk_style_context_add_class (context, "dim-label");
+        gtk_style_context_add_class (context, "event-monospace");
         gtk_label_set_xalign (GTK_LABEL (priv->category_label), 0);
         gtk_grid_attach (GTK_GRID (grid), priv->category_label,
                          rtl ? 2 : 0, 0, 1, 1);
@@ -247,14 +248,18 @@ gl_event_view_row_constructed (GObject *object)
     priv->time_label = gtk_label_new (time);
     context = gtk_widget_get_style_context (GTK_WIDGET (priv->time_label));
     gtk_style_context_add_class (context, "dim-label");
+    gtk_style_context_add_class (context, "event-monospace");
     gtk_style_context_add_class (context, "event-time");
     gtk_widget_set_halign (priv->time_label, GTK_ALIGN_END);
+    gtk_widget_set_hexpand (priv->time_label, TRUE);
     gtk_label_set_xalign (GTK_LABEL (priv->time_label), 1);
     gtk_grid_attach (GTK_GRID (grid), priv->time_label, rtl ? 0 : 2, 0, 1, 1);
 
     g_free (time);
     g_object_unref (tmp_entry);
 
+    gtk_widget_show_all (GTK_WIDGET (row));
+
     G_OBJECT_CLASS (gl_event_view_row_parent_class)->constructed (object);
 }
 
